@@ -1,22 +1,23 @@
-library(dplyr)
+library(dplyr, warn.conflicts = FALSE)
 library(r2dii.data)
 
 test_that("with fake data outputs known value", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   out <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(),
+    ald = fake_abcd(),
     scenario = fake_scenario(),
     region_isos = region_isos_stable
   )
-
-  expect_known_value(out, "ref-join_ald_scenario", update = FALSE)
+  expect_snapshot(out)
 })
 
 test_that("returns visibly", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   expect_visible(
     join_ald_scenario(
       fake_matched(),
-      ald = fake_ald(),
+      ald = fake_abcd(),
       scenario = fake_scenario(),
       region_isos = region_isos_stable
     )
@@ -24,10 +25,11 @@ test_that("returns visibly", {
 })
 
 test_that("outputs expected names", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   expected <- setdiff(
     c(
       names(fake_matched()),
-      names(fake_ald()),
+      names(fake_abcd()),
       names(fake_scenario()),
       # Comes from region_isos which is used internally
       "scenario_source"
@@ -37,7 +39,7 @@ test_that("outputs expected names", {
 
   out <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(),
+    ald = fake_abcd(),
     scenario = fake_scenario(),
     region_isos = region_isos_stable
   )
@@ -48,7 +50,7 @@ test_that("outputs expected names", {
 
   out2 <- join_ald_scenario(
     fake_matched(new_column = "anything"),
-    ald = fake_ald(),
+    ald = fake_abcd(),
     scenario = fake_scenario(),
     region_isos = region_isos_stable
   )
@@ -59,16 +61,17 @@ test_that("outputs expected names", {
 })
 
 test_that("is sensitive to region_isos", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   out1 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(),
+    ald = fake_abcd(),
     scenario = fake_scenario(scenario_source = "weo_2019"),
     region_isos = r2dii.data::region_isos
   )
 
   out2 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(),
+    ald = fake_abcd(),
     scenario = fake_scenario(scenario_source = "demo_2020"),
     region_isos = region_isos_stable
   )
@@ -77,10 +80,11 @@ test_that("is sensitive to region_isos", {
 })
 
 test_that("is case-insensitive to `plant_location` inputs", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   lowercase <- "a"
   out1 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(plant_location = lowercase),
+    ald = fake_abcd(plant_location = lowercase),
     scenario = fake_scenario(region = "b", scenario_source = "c"),
     region_isos = tibble(isos = "a", region = "b", source = "c")
   )
@@ -88,7 +92,7 @@ test_that("is case-insensitive to `plant_location` inputs", {
   uppercase <- "A"
   out2 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(plant_location = uppercase),
+    ald = fake_abcd(plant_location = uppercase),
     scenario = fake_scenario(region = "b", scenario_source = "c"),
     region_isos = tibble(isos = "a", region = "b", source = "c")
   )
@@ -97,10 +101,11 @@ test_that("is case-insensitive to `plant_location` inputs", {
 })
 
 test_that("outputs a number of rows equal to matches by `scenario_source`", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   matching_0 <- suppressWarnings(
     join_ald_scenario(
       fake_matched(),
-      ald = fake_ald(plant_location = "a"),
+      ald = fake_abcd(plant_location = "a"),
       scenario = fake_scenario(region = "b", scenario_source = "c"),
       region_isos = tibble(isos = "a", region = "b", source = "-")
     )
@@ -109,7 +114,7 @@ test_that("outputs a number of rows equal to matches by `scenario_source`", {
 
   matching_1 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(plant_location = "a"),
+    ald = fake_abcd(plant_location = "a"),
     scenario = fake_scenario(region = "b", scenario_source = "c"),
     region_isos = tibble(isos = "a", region = "b", source = "c")
   )
@@ -117,7 +122,7 @@ test_that("outputs a number of rows equal to matches by `scenario_source`", {
 
   matching_2 <- join_ald_scenario(
     fake_matched(),
-    ald = fake_ald(plant_location = "a"),
+    ald = fake_abcd(plant_location = "a"),
     scenario = fake_scenario(region = "b", scenario_source = c("c", "c")),
     region_isos = tibble(isos = "a", region = "b", source = "c")
   )
@@ -125,10 +130,11 @@ test_that("outputs a number of rows equal to matches by `scenario_source`", {
 })
 
 test_that("w/ loanbook, ald or scenario with missing names errors gracefully", {
-  bad <- function(data, x) rename(data, bad = x)
+  withr::local_options(lifecycle_verbosity = "quiet")
+  bad <- function(data, x) rename(data, bad = all_of(x))
 
   expect_error_missing_names <- function(match_result = fake_matched(),
-                                         ald = fake_ald(),
+                                         ald = fake_abcd(),
                                          scenario = fake_scenario()) {
     expect_error(
       class = "missing_names",
@@ -136,13 +142,13 @@ test_that("w/ loanbook, ald or scenario with missing names errors gracefully", {
     )
   }
 
-  expect_error_missing_names(match_result = bad(fake_matched(), "name_ald"))
-  expect_error_missing_names(match_result = bad(fake_matched(), "sector_ald"))
+  expect_error_missing_names(match_result = bad(fake_matched(), "name_abcd"))
+  expect_error_missing_names(match_result = bad(fake_matched(), "sector_abcd"))
 
-  expect_error_missing_names(ald = bad(fake_ald(), "name_company"))
-  expect_error_missing_names(ald = bad(fake_ald(), "sector"))
-  expect_error_missing_names(ald = bad(fake_ald(), "technology"))
-  expect_error_missing_names(ald = bad(fake_ald(), "year"))
+  expect_error_missing_names(ald = bad(fake_abcd(), "name_company"))
+  expect_error_missing_names(ald = bad(fake_abcd(), "sector"))
+  expect_error_missing_names(ald = bad(fake_abcd(), "technology"))
+  expect_error_missing_names(ald = bad(fake_abcd(), "year"))
 
   expect_error_missing_names(scenario = bad(fake_scenario(), "sector"))
   expect_error_missing_names(scenario = bad(fake_scenario(), "technology"))
@@ -152,12 +158,13 @@ test_that("w/ loanbook, ald or scenario with missing names errors gracefully", {
 })
 
 test_that("without `sector` throws no error", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   # 2DegreesInvesting/r2dii.analysis/pull/62#issuecomment-634651157
   without_sector <- select(fake_matched(), -sector)
   expect_error_free(
     join_ald_scenario(
       without_sector,
-      ald = fake_ald(),
+      ald = fake_abcd(),
       scenario = fake_scenario(),
       region_isos = region_isos_stable
     )
@@ -165,6 +172,7 @@ test_that("without `sector` throws no error", {
 })
 
 test_that("warns 0-rows caused by scenario or region_isos", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   join_ald_scenario2 <- function(l, scenario = NULL, region_isos = NULL) {
     scenario <- scenario %||% fake_scenario(
       region = l$region, sector = l$sector, scenario_source = l$source
@@ -174,8 +182,8 @@ test_that("warns 0-rows caused by scenario or region_isos", {
     )
 
     join_ald_scenario(
-      fake_matched(sector_ald = l$sector),
-      ald = fake_ald(plant_location = l$isos, sector = l$sector),
+      fake_matched(sector_abcd = l$sector),
+      ald = fake_abcd(plant_location = l$isos, sector = l$sector),
       scenario = scenario,
       region_isos = region_isos
     )
@@ -217,6 +225,7 @@ test_that("warns 0-rows caused by scenario or region_isos", {
 })
 
 test_that("include/excludes `plant_location` inside/outside a region", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   # styler: off
   region_isos_toy <- tribble(
     ~region,         ~isos, ~source,
@@ -232,7 +241,7 @@ test_that("include/excludes `plant_location` inside/outside a region", {
     # We have isos to match all countries and regions;
     region_isos = region_isos_toy,
     # And we have asset-level data from all countries;
-    ald = fake_ald(plant_location = c("de", "fr", "cn", "us")),
+    ald = fake_abcd(plant_location = c("de", "fr", "cn", "us")),
     # But our scenario if is only relevant to Europe and China -- not US
     scenario = fake_scenario(region = c("oecd", "china"))
   )
@@ -245,8 +254,9 @@ test_that("include/excludes `plant_location` inside/outside a region", {
 })
 
 test_that("outputs the same with upper/lower ald$sector or ald$technology", {
+  withr::local_options(lifecycle_verbosity = "quiet")
   matched <- fake_matched()
-  ald <- fake_ald()
+  ald <- fake_abcd()
   scenario <- fake_scenario()
   regions <- region_isos_stable
 
