@@ -4,9 +4,9 @@ library(r2dii.data)
 test_that("with fake data outputs known value", {
   out <- target_sda(
     fake_matched(
-      sector_ald = "cement"
+      sector_abcd = "cement"
     ),
-    ald = fake_ald(
+    abcd = fake_abcd(
       sector = "cement",
       technology = "cement",
       year = c(2020, 2021, 2022),
@@ -15,16 +15,17 @@ test_that("with fake data outputs known value", {
     co2_intensity_scenario = fake_co2_scenario(
       year = c(2020, 2050),
       emission_factor = c(0.6, 0.2)
-    )
+    ),
+    region_isos = region_isos_stable
   )
 
-  expect_known_value(out, "ref-target_sda", update = FALSE)
+  expect_snapshot(out)
 
   out_company <- target_sda(
     fake_matched(
-      sector_ald = "cement"
+      sector_abcd = "cement"
     ),
-    ald = fake_ald(
+    abcd = fake_abcd(
       sector = "cement",
       technology = "cement",
       year = c(2020, 2021, 2022),
@@ -34,43 +35,46 @@ test_that("with fake data outputs known value", {
       year = c(2020, 2050),
       emission_factor = c(0.6, 0.2)
     ),
-    by_company = TRUE
+    by_company = TRUE,
+    region_isos = region_isos_stable
   )
 
-  expect_known_value(out_company, "ref-target_sda_company", update = TRUE)
+  expect_snapshot(out_company)
 })
 
 test_that("outputs is ungrouped", {
   out <- target_sda(
     fake_matched(
-      sector_ald = "cement"
+      sector_abcd = "cement"
     ),
-    fake_ald(
+    fake_abcd(
       sector = "cement",
       year = c(2020, 2050)
     ),
     co2_intensity_scenario = fake_co2_scenario(
       emission_factor = c(1, 2),
       year = c(2020, 2050)
-    )
+    ),
+    region_isos = region_isos_stable
   )
   expect_false(dplyr::is_grouped_df(out))
 })
 
 test_that("warns when input data is grouped", {
-  grouped_data <- group_by(fake_matched(sector_ald = "cement"), id_loan)
+  grouped_data <- group_by(fake_matched(sector_abcd = "cement"), id_loan)
 
   out <- function() {
     target_sda(
       grouped_data,
-      ald = fake_ald(
+      abcd = fake_abcd(
         sector = "cement",
         year = c(2020, 2050)
       ),
       co2_intensity_scenario = fake_co2_scenario(
         emission_factor = c(1, 2),
         year = c(2020, 2050)
-      )
+      ),
+      region_isos = region_isos_stable
     )
   }
 
@@ -79,7 +83,7 @@ test_that("warns when input data is grouped", {
 
 test_that("with bad `data` errors with informative message", {
   expect_error(
-    target_sda("bad", fake_ald(), fake_co2_scenario()),
+    target_sda("bad", fake_abcd(), fake_co2_scenario()),
     "data.frame.*not.*TRUE"
   )
   expect_error(
@@ -87,13 +91,13 @@ test_that("with bad `data` errors with informative message", {
     "data.frame.*not.*TRUE"
   )
   expect_error(
-    target_sda(fake_matched(), fake_ald(), "bad"),
+    target_sda(fake_matched(), fake_abcd(), "bad"),
     "data.frame.*not.*TRUE"
   )
   expect_error(
     target_sda(
       fake_matched(),
-      ald = fake_ald(),
+      abcd = fake_abcd(),
       co2_intensity_scenario = fake_co2_scenario(),
       use_credit_limit = "bad"
     ),
@@ -105,25 +109,25 @@ test_that("w/ missing crucial names errors gracefully", {
   bad <- function(data, x) rename(data, bad = dplyr::one_of(x))
 
   expect_error_missing_names <- function(match_result = fake_matched(),
-                                         ald = fake_ald(),
+                                         abcd = fake_abcd(),
                                          scenario = fake_co2_scenario()) {
     expect_error(
       class = "missing_names",
-      target_sda(match_result, ald, scenario)
+      target_sda(match_result, abcd, scenario)
     )
   }
 
   mch <- fake_matched()
   expect_error_missing_names(match_result = bad(mch, "loan_size_outstanding"))
   expect_error_missing_names(match_result = bad(mch, "loan_size_credit_limit"))
-  expect_error_missing_names(match_result = bad(mch, "name_ald"))
-  expect_error_missing_names(match_result = bad(mch, "sector_ald"))
+  expect_error_missing_names(match_result = bad(mch, "name_abcd"))
+  expect_error_missing_names(match_result = bad(mch, "sector_abcd"))
 
-  expect_error_missing_names(ald = bad(fake_ald(), "name_company"))
-  expect_error_missing_names(ald = bad(fake_ald(), "sector"))
-  expect_error_missing_names(ald = bad(fake_ald(), "year"))
-  expect_error_missing_names(ald = bad(fake_ald(), "emission_factor"))
-  expect_error_missing_names(ald = bad(fake_ald(), "production"))
+  expect_error_missing_names(abcd = bad(fake_abcd(), "name_company"))
+  expect_error_missing_names(abcd = bad(fake_abcd(), "sector"))
+  expect_error_missing_names(abcd = bad(fake_abcd(), "year"))
+  expect_error_missing_names(abcd = bad(fake_abcd(), "emission_factor"))
+  expect_error_missing_names(abcd = bad(fake_abcd(), "production"))
 
   scen <- fake_co2_scenario()
   expect_error_missing_names(scenario = bad(scen, "sector"))
@@ -133,12 +137,13 @@ test_that("w/ missing crucial names errors gracefully", {
 
 test_that("without `sector` throws no error", {
   # 2DegreesInvesting/r2dii.analysis/pull/62#issuecomment-634651157
-  without_sector <- select(fake_matched(sector_ald = "cement"), -sector)
+  without_sector <- select(fake_matched(sector_abcd = "cement"), -sector)
   expect_error_free(
     target_sda(
       without_sector,
-      ald = fake_ald(sector = "cement"),
-      co2_intensity_scenario = fake_co2_scenario()
+      abcd = fake_abcd(sector = "cement"),
+      co2_intensity_scenario = fake_co2_scenario(),
+      region_isos = region_isos_stable
     )
   )
 })
@@ -149,10 +154,10 @@ test_that("properly weights emissions factors", {
   out <- target_sda(
     fake_matched(
       id_loan = c(1, 2),
-      name_ald = companies,
-      sector_ald = "cement"
+      name_abcd = companies,
+      sector_abcd = "cement"
     ),
-    ald = fake_ald(
+    abcd = fake_abcd(
       name_company = companies,
       sector = "cement",
       technology = "cement",
@@ -162,7 +167,8 @@ test_that("properly weights emissions factors", {
     co2_intensity_scenario = fake_co2_scenario(
       year = c(2020, 2050),
       emission_factor = c(0.6, 0.2)
-    )
+    ),
+    region_isos = region_isos_stable
   )
 
   initial_data <- out %>%
@@ -176,8 +182,8 @@ test_that("properly weights emissions factors", {
 
 test_that("outputs expected names", {
   out <- target_sda(
-    fake_matched(sector_ald = "cement"),
-    ald = fake_ald(
+    fake_matched(sector_abcd = "cement"),
+    abcd = fake_abcd(
       sector = "cement",
       technology = "cement",
       year = c(2020, 2021, 2022),
@@ -185,18 +191,26 @@ test_that("outputs expected names", {
     ),
     co2_intensity_scenario = fake_co2_scenario(
       year = c(2020, 2050), emission_factor = c(0.6, 0.2)
-    )
+    ),
+    region_isos = region_isos_stable
   )
 
-  exp <- c("sector", "year", "emission_factor_metric", "emission_factor_value")
-  expect_named(out, exp)
+  expected_names <- c(
+    "sector",
+    "year",
+    "region",
+    "scenario_source",
+    "emission_factor_metric",
+    "emission_factor_value"
+  )
+  expect_named(out, expected_names)
 })
 
 test_that("with known input outputs as expected", {
   # TODO: Re-factor this test into smaller isolated expected output tests
-  matched <- fake_matched(sector_ald = "cement")
+  matched <- fake_matched(sector_abcd = "cement")
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     sector = "cement",
     technology = "cement",
     name_company = c(rep("shaanxi auto", 4), "company 2"),
@@ -210,7 +224,12 @@ test_that("with known input outputs as expected", {
     emission_factor = c(0.5, 0.1, 0.5, 0.4)
   )
 
-  out <- target_sda(matched, ald, co2_intensity_scenario) %>%
+  out <- target_sda(
+    matched,
+    abcd,
+    co2_intensity_scenario,
+    region_isos = region_isos_stable
+  ) %>%
     arrange(.data$year) %>%
     split(.$emission_factor_metric)
 
@@ -237,33 +256,39 @@ test_that("with known input outputs as expected", {
 })
 
 test_that("with no matching data warns", {
-  no_matches <- fake_matched(sector_ald = "bad")
+  no_matches <- fake_matched(sector_abcd = "bad")
 
   if (packageVersion("testthat") >= "2.99.0.9000") {
     expect_warning(
       class = "no_match",
-      target_sda(no_matches, fake_ald(), fake_co2_scenario())
+      target_sda(no_matches, fake_abcd(), fake_co2_scenario())
     )
   } else {
     expect_warning(
-      target_sda(no_matches, fake_ald(), fake_co2_scenario()), "no match"
+      target_sda(no_matches, fake_abcd(), fake_co2_scenario()), "no match"
     )
   }
 
   bad_scenario <- fake_co2_scenario(sector = "bad")
   expect_warning(
-    target_sda(fake_matched(), fake_ald(), bad_scenario), "no scenario"
+    target_sda(
+      fake_matched(),
+      fake_abcd(),
+      bad_scenario,
+      region_isos = region_isos_stable
+      ),
+    class = "no_match"
   )
 })
 
 test_that("with duplicated id_loan weights emission_factor as expected (#160)", {
   match_result <- fake_matched(
     id_loan = c(1, 1),
-    name_ald = rep("large company", 2),
-    sector_ald = "cement"
+    name_abcd = rep("large company", 2),
+    sector_abcd = "cement"
   )
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     sector = "cement",
     name_company = "large company",
     emission_factor = 2,
@@ -278,8 +303,9 @@ test_that("with duplicated id_loan weights emission_factor as expected (#160)",
   expect_error(
     target_sda(
       match_result,
-      ald,
-      scen
+      abcd,
+      scen,
+      region_isos = region_isos_stable
     ) %>%
       filter(year == min(year)),
     class = "unique_ids"
@@ -288,9 +314,9 @@ test_that("with duplicated id_loan weights emission_factor as expected (#160)",
 
 test_that("with NAs in crucial columns errors with informative message (#146)", {
   expect_error_crucial_NAs_portfolio <- function(name) {
-    data <- fake_matched(sector_ald = "cement")
+    data <- fake_matched(sector_abcd = "cement")
 
-    ald <- fake_ald(
+    abcd <- fake_abcd(
       sector = "cement",
       year = c(2020, 2050)
     )
@@ -305,16 +331,17 @@ test_that("with NAs in crucial columns errors with informative message (#146)",
       class = "some_value_is_missing",
       target_sda(
         data,
-        ald,
-        scen
+        abcd,
+        scen,
+        region_isos = region_isos_stable
       )
     )
   }
 
-  expect_error_crucial_NAs_ald <- function(name) {
-    match_result <- fake_matched(sector_ald = "cement")
+  expect_error_crucial_NAs_abcd <- function(name) {
+    match_result <- fake_matched(sector_abcd = "cement")
 
-    data <- fake_ald(
+    data <- fake_abcd(
       sector = "cement",
       year = c(2020, 2050)
     )
@@ -331,15 +358,16 @@ test_that("with NAs in crucial columns errors with informative message (#146)",
       target_sda(
         match_result,
         data,
-        scen
+        scen,
+        region_isos = region_isos_stable
       )
     )
   }
 
   expect_error_crucial_NAs_scenario <- function(name) {
-    match_result <- fake_matched(sector_ald = "cement")
+    match_result <- fake_matched(sector_abcd = "cement")
 
-    ald <- fake_ald(
+    abcd <- fake_abcd(
       sector = "cement",
       year = c(2020, 2050)
     )
@@ -355,19 +383,20 @@ test_that("with NAs in crucial columns errors with informative message (#146)",
       class = "some_value_is_missing",
       target_sda(
         match_result,
-        ald,
-        data
+        abcd,
+        data,
+        region_isos = region_isos_stable
       )
     )
   }
 
-  expect_error_crucial_NAs_portfolio("name_ald")
-  expect_error_crucial_NAs_portfolio("sector_ald")
+  expect_error_crucial_NAs_portfolio("name_abcd")
+  expect_error_crucial_NAs_portfolio("sector_abcd")
 
-  expect_error_crucial_NAs_ald("name_company")
-  expect_error_crucial_NAs_ald("production")
-  expect_error_crucial_NAs_ald("sector")
-  expect_error_crucial_NAs_ald("year")
+  expect_error_crucial_NAs_abcd("name_company")
+  expect_error_crucial_NAs_abcd("production")
+  expect_error_crucial_NAs_abcd("sector")
+  expect_error_crucial_NAs_abcd("year")
 
   expect_error_crucial_NAs_scenario("sector")
   expect_error_crucial_NAs_scenario("year")
@@ -377,11 +406,11 @@ test_that("with NAs in crucial columns errors with informative message (#146)",
 test_that("with multiple technologies weights emission_factor as expected (#160)", {
   match_result <- fake_matched(
     id_loan = c(1, 2),
-    name_ald = rep("large company", 2),
-    sector_ald = "cement"
+    name_abcd = rep("large company", 2),
+    sector_abcd = "cement"
   )
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     sector = "cement",
     name_company = "large company",
     technology = rep(c("a", "b"), 2),
@@ -396,8 +425,9 @@ test_that("with multiple technologies weights emission_factor as expected (#160)
 
   out <- target_sda(
     match_result,
-    ald,
-    scen
+    abcd,
+    scen,
+    region_isos = region_isos_stable
   ) %>%
     filter(year == min(year)) %>%
     split(.$emission_factor_metric)
@@ -408,8 +438,8 @@ test_that("with multiple technologies weights emission_factor as expected (#160)
 
 test_that("with multiple technologies, aggregates production-weighted emission_factor (#160)", {
   out <- target_sda(
-    fake_matched(sector_ald = "cement"),
-    ald = fake_ald(
+    fake_matched(sector_abcd = "cement"),
+    abcd = fake_abcd(
       sector = "cement",
       technology = c("cement 1", "cement 2"),
       year = 2020,
@@ -418,7 +448,8 @@ test_that("with multiple technologies, aggregates production-weighted emission_f
     ),
     co2_intensity_scenario = fake_co2_scenario(
       year = c(2020, 2050), emission_factor = c(0.6, 0.2)
-    )
+    ),
+    region_isos = region_isos_stable
   ) %>%
     split(.$emission_factor_metric)
 
@@ -427,8 +458,8 @@ test_that("with multiple technologies, aggregates production-weighted emission_f
 
 test_that("with multiple plant_location, aggregates production-weighted emission_factor (#160)", {
   out <- target_sda(
-    fake_matched(sector_ald = "cement"),
-    ald = fake_ald(
+    fake_matched(sector_abcd = "cement"),
+    abcd = fake_abcd(
       sector = "cement",
       plant_location = c("de", "fr"),
       year = 2020,
@@ -437,8 +468,10 @@ test_that("with multiple plant_location, aggregates production-weighted emission
     ),
     co2_intensity_scenario = fake_co2_scenario(
       year = c(2020, 2050), emission_factor = c(0.6, 0.2)
-    )
+    ),
+    region_isos = region_isos_stable
   ) %>%
+    filter(region == "global") %>%
     split(.$emission_factor_metric)
 
   expect_equal(out$corporate_economy$emission_factor_value, 100)
@@ -449,8 +482,8 @@ test_that("filters and warns when input-data has NAs", {
   # https://gist.github.com/maurolepore/c04388c6d4795561fb168172e75154c0
   .object <- rlang::expr(
     out <- target_sda(
-      fake_matched(sector_ald = "cement"),
-      ald = fake_ald(
+      fake_matched(sector_abcd = "cement"),
+      abcd = fake_abcd(
         sector = "cement",
         technology = rep(c("cement", "bad"), 2),
         year = rep(c(2020, 2050), 2),
@@ -458,7 +491,8 @@ test_that("filters and warns when input-data has NAs", {
       ),
       co2_intensity_scenario = fake_co2_scenario(
         year = c(2020, 2050), emission_factor = c(0.6, 0.2)
-      )
+      ),
+      region_isos = region_isos_stable
     )
   )
   if (packageVersion("testthat") >= "2.99.0.9000") {
@@ -473,21 +507,22 @@ test_that("filters and warns when input-data has NAs", {
 })
 
 test_that(
-  "`sector` column is not used from data (should only use `sector_ald`) (#178)",
+  "`sector` column is not used from data (should only use `sector_abcd`) (#178)",
   {
     expect_error_free(
       target_sda(
         fake_matched(
-          sector_ald = "cement"
+          sector_abcd = "cement"
         ) %>% select(-sector),
-        fake_ald(
+        fake_abcd(
           sector = "cement",
           year = c(2020, 2050)
         ),
         co2_intensity_scenario = fake_co2_scenario(
           emission_factor = c(1, 2),
           year = c(2020, 2050)
-        )
+        ),
+        region_isos = region_isos_stable
       )
     )
   }
@@ -497,7 +532,7 @@ test_that("with multiple values of `country_of_domicile` outputs the expected
           `emission_factor_value` (#171)", {
   this_company <- "company"
   this_sector <- "steel"
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     country_of_domicile = c("a", "b"),
     emission_factor = 0.5,
     year = 2020,
@@ -506,26 +541,30 @@ test_that("with multiple values of `country_of_domicile` outputs the expected
   )
 
   matched <- fake_matched(
-    name_ald = this_company,
+    name_abcd = this_company,
     sector = this_sector,
-    sector_ald = this_sector
+    sector_abcd = this_sector
   )
 
   out <- matched %>%
-    target_sda(ald, co2_intensity_scenario_demo) %>%
+    target_sda(
+      abcd,
+      co2_intensity_scenario_demo,
+      region_isos = region_isos_stable
+    ) %>%
     split(.$emission_factor_metric)
 
   expect_equal(out$projected$emission_factor_value, 0.5)
 })
 
-test_that("outputs same target regardless of years present in ald", {
+test_that("outputs same target regardless of years present in abcd", {
   matched <- fake_matched(
-    name_ald = "company a",
-    sector_ald = "steel"
+    name_abcd = "company a",
+    sector_abcd = "steel"
   )
 
 
-  ald_ten_year <- fake_ald(
+  abcd_ten_year <- fake_abcd(
     sector = "steel",
     technology = "steel",
     name_company = c(rep("company a", 3), rep("company b", 3)),
@@ -534,7 +573,7 @@ test_that("outputs same target regardless of years present in ald", {
     plant_location = "DE"
   )
 
-  ald_thirty_year <- fake_ald(
+  abcd_thirty_year <- fake_abcd(
     sector = "steel",
     technology = "steel",
     name_company = c(rep("company a", 4), rep("company b", 4)),
@@ -549,13 +588,23 @@ test_that("outputs same target regardless of years present in ald", {
     emission_factor = c(2, 1.9, 1.8, 0.25)
   )
 
-  out_ten_year <- target_sda(matched, ald_ten_year, co2_scenario) %>%
+  out_ten_year <- target_sda(
+    matched,
+    abcd_ten_year,
+    co2_scenario,
+    region_isos = region_isos_stable
+  ) %>%
     filter(
       year == 2030,
       emission_factor_metric == "target_b2ds"
     )
 
-  out_thirty_year <- target_sda(matched, ald_thirty_year, co2_scenario) %>%
+  out_thirty_year <- target_sda(
+    matched,
+    abcd_thirty_year,
+    co2_scenario,
+    region_isos = region_isos_stable
+  ) %>%
     filter(
       year == 2030,
       emission_factor_metric == "target_b2ds"
@@ -570,10 +619,10 @@ test_that("outputs same target regardless of years present in ald", {
 test_that("outputs only sectors present in `co2_intensity_scenario` (#308)", {
   matched <- fake_matched(
     id_loan = c("L1", "L2"),
-    sector_ald = c("cement", "power")
+    sector_abcd = c("cement", "power")
   )
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     sector = c("cement", "power"),
   )
 
@@ -583,7 +632,12 @@ test_that("outputs only sectors present in `co2_intensity_scenario` (#308)", {
     year = c(2025, 2026)
   )
 
-  out <- target_sda(matched, ald, co2_scenario)
+  out <- target_sda(
+    matched,
+    abcd,
+    co2_scenario,
+    region_isos = region_isos_stable
+  )
 
   out_sectors <- unique(out$sector)
   scenario_sectors <- unique(co2_scenario$sector)
@@ -594,13 +648,13 @@ test_that("outputs only sectors present in `co2_intensity_scenario` (#308)", {
   )
 })
 
-test_that("doesn't output NAs if ald and scenario years are misaligned (#307,
+test_that("doesn't output NAs if abcd and scenario years are misaligned (#307,
           #346)", {
   matched <- fake_matched(
-    sector_ald = "cement"
+    sector_abcd = "cement"
   )
 
-  ald <- fake_ald(
+  abcd <- fake_abcd(
     sector = "cement",
     year = c(2024, 2025)
   )
@@ -610,9 +664,103 @@ test_that("doesn't output NAs if ald and scenario years are misaligned (#307,
     year = c(2023, 2025, 2026)
   )
 
-  out <- target_sda(matched, ald, co2_scenario)
+  out <- target_sda(
+    matched,
+    abcd,
+    co2_scenario,
+    region_isos = region_isos_stable
+  )
 
   expect_false(
     any(is.na(out$emission_factor_value))
   )
 })
+
+test_that("output useful error message when emission_factor is not of type double (#224)", {
+  matched <- fake_matched()
+  abcd <- fake_abcd()
+  co2_intensity_scenario <- fake_co2_scenario()
+
+  bad_abcd <- abcd %>%
+    mutate(
+      emission_factor = as.character(emission_factor)
+    )
+
+  expect_error(
+    class = "crucial_column_wrong_type",
+    target_sda(
+      matched,
+      bad_abcd,
+      co2_intensity_scenario,
+      region_isos = region_isos_stable
+    )
+  )
+})
+
+test_that("argument `weight_emission_factor` outputs correctly with known input (#376)", {
+  matched <- fake_matched(
+    id_loan = c("L1", "L2"),
+    name_abcd = c("american cement", "boral cement"),
+    sector = "cement",
+    sector_abcd = "cement"
+  )
+
+  abcd <- fake_abcd(
+    name_company = rep(c("american cement", "boral cement"), 2),
+    sector = "cement",
+    technology = "cement integrated facility",
+    year = rep(c(2020, 2021), each = 2),
+    emission_factor = rep(c(0.7, 0.5), 2)
+  )
+
+  out <- matched %>%
+    target_sda(
+      abcd,
+      fake_co2_scenario(year = c(2020, 2021), emission_factor = c(1, 0.7)),
+      by_company = TRUE,
+      region_isos = region_isos_stable
+    ) %>%
+    filter(year == 2020, emission_factor_metric == "target_b2ds") %>%
+    split(.$name_abcd)
+
+
+  abcd <- abcd %>%
+    filter(!is.na(emission_factor), year == 2020) %>%
+    select(name_company, year, emission_factor) %>%
+    split(.$name_company)
+
+  expect_equal(
+    out$`american cement`$emission_factor_value,
+    abcd$`american cement`$emission_factor
+  )
+
+  expect_equal(
+    out$`boral cement`$emission_factor_value,
+    abcd$`boral cement`$emission_factor
+  )
+})
+
+test_that("outputs empty tibble for sectors in `scenario` and `abcd` but not
+          `data` (#390)", {
+
+  abcd <- fake_abcd(
+    sector = c("cement", "steel")
+  )
+
+  scenario <- fake_co2_scenario(
+    sector = rep(c("cement", "steel"), each = 2),
+    year = rep(c(2025, 2026), 2),
+    emission_factor = rep(c(1, 2), 2)
+  )
+
+  out <- target_sda(
+    fake_matched(sector_abcd = "cement"),
+    abcd,
+    scenario,
+    region_isos = region_isos_stable
+  )
+
+  out_steel <- filter(out, sector == "steel")
+
+  expect_equal(nrow(out_steel), 0L)
+})
